Module case

Module case 

The EvaluationCase trait — the unit of evaluation.

Implement this trait for any scenario you want to evaluate N times.

Structs

AlwaysFailCase
A no-op evaluation case that always fails — useful for testing failure paths.
AlwaysPassCase
A minimal no-op evaluation case useful for unit-testing the evaluation infrastructure itself.
StochasticCase
A case that succeeds with a configurable probability (for testing statistics).

Traits

EvaluationCase
A single evaluation scenario.