The EvaluationCase trait — the unit of evaluation.
Implement this trait for any scenario you want to evaluate N times.
Structs
- Always
Fail Case - A no-op evaluation case that always fails — useful for testing failure paths.
- Always
Pass Case - A minimal no-op evaluation case useful for unit-testing the evaluation infrastructure itself.
- Stochastic
Case - A case that succeeds with a configurable probability (for testing statistics).
Traits
- Evaluation
Case - A single evaluation scenario.